@@ -3,17 +3,24 @@ from emoji.unicode_codes import UNICODE_EMOJI
 
 from nonebot import on_regex
 from nonebot.params import RegexDict
+from nonebot.plugin import PluginMetadata
 from nonebot.adapters.onebot.v11 import MessageSegment
 
+from .config import Config
 from .data_source import mix_emoji
 
-
-__help__plugin_name__ = "emojimix"
-__des__ = "emoji合成器"
-__cmd__ = "{emoji1}+{emoji2}"
-__short_cmd__ = __cmd__
-__example__ = "😎+😁"
-__usage__ = f"{__des__}\nUsage:\n{__cmd__}\nExample:\n{__example__}"
+__plugin_meta__ = PluginMetadata(
+    name="emoji合成",
+    description="将两个emoji合成为一张图片",
+    usage="{emoji1}+{emoji2}，如：😎+😁",
+    config=Config,
+    extra={
+        "unique_name": "emojimix",
+        "example": "😎+😁",
+        "author": "meetwq <meetwq@gmail.com>",
+        "version": "0.1.7",
+    },
+)
 
 
 emojis = filter(lambda e: len(e) == 1, UNICODE_EMOJI["en"])
